@@ -19,9 +19,7 @@ from __future__ import division
 from __future__ import unicode_literals
 
 import collections
-import re
 import sys
-from typing import Any
 
 from googlecloudsdk.calliope import arg_parsers
 from googlecloudsdk.calliope import base
@@ -45,6 +43,20 @@ INSTANCE_TEMPLATE_ARG = compute_flags.ResourceArgument(
     """,
 )
 
+MULTI_MIG_ARG = compute_flags.ResourceArgument(
+    '--multi-mig',
+    resource_name='multi-MIG',
+    required=False,
+    plural=False,
+    scope_flags_usage=compute_flags.ScopeFlagsUsage.USE_EXISTING_SCOPE_FLAGS,
+    regional_collection='compute.regionMultiMigs',
+    region_help_text="""
+    Specifies the name or URL of the multi-MIG that will be attached to selected
+    managed instance group.
+    """,
+    region_hidden=True,
+)
+
 DEFAULT_CREATE_OR_LIST_FORMAT = """\
     table(
       name,
@@ -792,52 +804,6 @@ def AddMigResourceManagerTagsFlags(parser):
   )
 
 
-def AddInstanceFlexibilityPolicyArgs(
-    parser: Any,
-    is_update: bool = False,
-) -> None:
-  """Adds instance flexibility policy args."""
-  parser.add_argument(
-      '--instance-selection-machine-types',
-      type=arg_parsers.ArgList(),
-      metavar='MACHINE_TYPE',
-      help=(
-          'Machine types that are used to create VMs in the managed instance'
-          ' group. If not provided, the machine type specified in the instance'
-          ' template is used.'
-      ),
-  )
-  parser.add_argument(
-      '--instance-selection',
-      help=(
-          'Named selection of machine types with an optional rank. '
-          'For example,'
-          ' `--instance-selection="name=instance-selection-1,machine-type=e2-standard-8,machine-type=t2d-standard-8,rank=0"`'
-      ),
-      metavar='name=NAME,machine-type=MACHINE_TYPE[,machine-type=MACHINE_TYPE...][,rank=RANK]',
-      type=ArgMultiValueDict(),
-      action=arg_parsers.FlattenAction(),
-  )
-  if is_update:
-    parser.add_argument(
-        '--remove-instance-selections-all',
-        action='store_true',
-        help=(
-            'Remove all instance selections from the instance flexibility'
-            ' policy.'
-        ),
-    )
-    parser.add_argument(
-        '--remove-instance-selections',
-        type=arg_parsers.ArgList(),
-        metavar='INSTANCE_SELECTION_NAME',
-        help=(
-            'Remove specific instance selections from the instance flexibility'
-            ' policy.'
-        ),
-    )
-
-
 def AddTargetSizePolicyModeFlag(parser):
   """Add target size policy mode to the parser."""
   help_text = 'Specifies the mode in which the MIG creates VMs in the group.'
@@ -896,47 +862,6 @@ def AddWorkloadPolicyFlags(parser: parser_arguments.ArgumentInterceptor):
   AddRemoveWorkloadPolicyFlag(workload_policy_group)
 
 
-class ArgMultiValueDict:
-  """Converts argument values into multi-valued mappings.
-
-  Values for repeated keys are collected in a list. Ensures all values are
-  key-value pairs and handles invalid cases.
-  """
-
-  def __init__(self):
-    ops = '='
-    key_op_value_pattern = r'([^\s{ops}]+)\s*{ops}\s*(.*)'.format(ops=ops)
-    self._key_op_value = re.compile(key_op_value_pattern, re.DOTALL)
-
-  def __call__(self, arg_value):
-    arg_list = [item.strip() for item in arg_value.split(',')]
-    arg_dict = collections.OrderedDict()
-    for arg in arg_list:
-      # Enforce key-value pair structure
-      if '=' not in arg:
-        raise arg_parsers.ArgumentTypeError(
-            'Invalid flag value [{0}]'.format(arg)
-        )
-      match = self._key_op_value.match(arg)
-      if not match:
-        raise arg_parsers.ArgumentTypeError(
-            'Invalid flag value [{0}]'.format(arg)
-        )
-      key, value = match.group(1).strip(), match.group(2).strip()
-      if not key or not value:
-        raise arg_parsers.ArgumentTypeError(
-            'Invalid flag value [{0}]'.format(arg)
-        )
-      # Prevent values from containing '='
-      if '=' in value:
-        raise arg_parsers.ArgumentTypeError(
-            'Invalid flag value [{0}]'.format(arg)
-        )
-      arg_dict.setdefault(key, []).append(value)
-
-    return arg_dict
-
-
 def AddOnRepairFlags(parser: parser_arguments.ArgumentInterceptor):
   """Add on repair flags to the parser."""
   allow_changing_zone_choices = {
@@ -950,3 +875,17 @@ def AddOnRepairFlags(parser: parser_arguments.ArgumentInterceptor):
       choices=allow_changing_zone_choices,
       help="Specifies whether the MIG can change a VM's zone during a repair.",
   )
+
+
+def AddMultiMigFlags(parser):
+  """Adds Multi-MIG flags to the parser."""
+  multi_mig_group = parser.add_mutually_exclusive_group(hidden=True)
+  multi_mig_group.add_argument(
+      '--clear-multi-mig',
+      action='store_true',
+      default=None,
+      help="""\
+      Removes this managed instance group from the Multi-MIG it belongs to.
+      """,
+  )
+  MULTI_MIG_ARG.AddArgument(multi_mig_group)
